TimeDisplayMode enum

时间显示模式枚举

Inheritance
Available extensions

Values

relative → const TimeDisplayMode

相对时间模式 (几分钟前、几小时前等)

smart → const TimeDisplayMode

智能模式 (综合相对时间和智能显示的最佳体验)

  • 1小时内:显示相对时间 (如 "30分钟前")
  • 今天超过1小时:显示时间 (如 "14:30")
  • 昨天/明天:显示 "昨天/明天 时间"
  • 本周:显示 "周几 时间"
  • 今年:显示 "月日 时间"
  • 其他:显示 "年月日 时间"

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TimeDisplayMode>
A constant List of the values in this enum, in order of their declaration.