StringRegexExtension extension

字符串正则验证扩展

on

Methods

isDate() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of date which pattern is 'yyyy-MM-dd'.
isEmail() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of email.
isIDCard() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of id card number.
isIDCard15() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of id card number which length is 15.
isIDCard18() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of id card number which length is 18.
isIP() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of ip address.
isMobileExact() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of exact mobile.
isMobileSimple() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of simple mobile.
isPassport() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of Passport.
isQQ() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of QQ.
isTel() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of telephone number.
isURL() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of url.
isUserName() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of username.
isZh() bool

Available on String, provided by the StringRegexExtension extension

Return whether input matches regex of Chinese character.
matches(String regex) bool

Available on String, provided by the StringRegexExtension extension

Constants

regexChinaPostalCode → const String
Regex of postal code in China.
regexDate → const String
Regex of date which pattern is 'yyyy-MM-dd'.
regexEmail → const String
Regex of email.
regexIdCard15 → const String
Regex of id card number which length is 15.
regexIdCard18 → const String
Regex of id card number which length is 18.
regexIp → const String
Regex of ip address.
regexMobileExact → const String
Regex of exact mobile.
regexMobileSimple → const String
Regex of simple mobile.
regexPassport → const String
Regex of Passport.
regexQQ → const String
Regex of QQ number.
regexTel → const String
Regex of telephone number.
regexUrl → const String
Regex of url.
regexUsername → const String
must contain letters and numbers, 6 ~ 18. 必须包含字母和数字, 6~18.
regexUsername2 → const String
must contain letters and numbers, can contain special characters 6 ~ 18. 必须包含字母和数字,可包含特殊字符 6~18.
regexUsername3 → const String
must contain letters and numbers and special characters, 6 ~ 18. 必须包含字母和数字和殊字符, 6~18.
regexZh → const String
Regex of Chinese character.