AssetsPickerUtil class abstract

拍照工具类

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pickFromCamera(BuildContext context, {bool canRecording = false, bool onlyEnableRecording = false, bool shouldDeletePreviewFile = true, bool enableAudio = false, Duration maximumRecordingDuration = const Duration(seconds: 15), PickerResolution resolutionPreset = PickerResolution.high, void onCaptured(List<File>)?, void onError(Object error, StackTrace? stackTrace)?}) Future<File?>
相机拍摄
pickFromGallery(BuildContext context, {int maxAssets = defaultMaxAssetsCount, bool canRecording = false}) Future<List<File>>
从相册获取