PickerResolution enum
拍摄分辨率
Values
- low → const PickerResolution
-
352x288 on iOS, ~240p on Android and Web
- medium → const PickerResolution
-
~480p
- high → const PickerResolution
-
~720p
- veryHigh → const PickerResolution
-
~1080p
- ultraHigh → const PickerResolution
-
~2160p
- max → const PickerResolution
-
The highest resolution available.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - resolutionPreset → ResolutionPreset
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PickerResolution> - A constant List of the values in this enum, in order of their declaration.