ConnectivityStatus enum

网络状态枚举

Inheritance
Available extensions

Values

mobile → const ConnectivityStatus
const ConnectivityStatus('mobile', '移动网络')
wifi → const ConnectivityStatus
const ConnectivityStatus('wifi', 'Wi-Fi')
ethernet → const ConnectivityStatus
const ConnectivityStatus('ethernet', '以太网')
vpn → const ConnectivityStatus
const ConnectivityStatus('vpn', 'VPN')
bluetooth → const ConnectivityStatus
const ConnectivityStatus('bluetooth', '蓝牙')
other → const ConnectivityStatus
const ConnectivityStatus('other', '其他')
none → const ConnectivityStatus
const ConnectivityStatus('none', '无')

Properties

hashCode int
The hash code for this object.
no setterinherited
hasInternet bool
是否有网络
no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
isMobile bool
是否是移动网络
no setter
isWifi bool
是否是Wi-Fi
no setter
name String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nameZh String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ConnectivityStatus>
A constant List of the values in this enum, in order of their declaration.