ConnectivityUtil class
网络状态工具类
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
connectivityController
→ StreamController<
ConnectivityStatus> -
no setter
Static Methods
-
checkConnectivity(
) → Future< ConnectivityStatus> - 检查网络状态
-
listenConnectivityChanged(
StatusChangedCallback onStatusChanged) → StreamSubscription< ConnectivityStatus> -
监听网络状态
onStatusChanged网络状态回调