ImageUtil class abstract

Constructors

ImageUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

asset(String assetPath, {Color? color, double? width, double? height, BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, PlaceholderBuilder? placeholderBuilder, String? package}) Widget
加载本地资源图片
assetsProvider(String asssetPath, {Size? size, double scale = 1.0}) ImageProvider<Object>
file(File file, {Color? color, double? width, double? height, BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, PlaceholderBuilder? placeholderBuilder}) Widget
加载本地图片文件
network(String imageUrl, {Color? color, double? width, double? height, BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, PlaceholderBuilder? placeholderBuilder}) Widget
加载网络图片
networkProvider(String imageUrl, {Size? size, double scale = 1.0}) ImageProvider<Object>