AppInfo class

应用信息

Constructors

AppInfo({required String appName, required String packageName, required String version, required String buildNumber, DateTime? installTime, DateTime? updateTime})

Properties

appName String
应用名称
final
buildNumber String
build版本号
final
data Map<String, dynamic>
no setter
hashCode int
The hash code for this object.
no setterinherited
installTime DateTime?
安装时间
final
mode String
是否是debug模式
no setter
packageName String
包名
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateTime DateTime?
更新时间
final
version String
版本号
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited