DeviceInfo class

设备信息

Constructors

DeviceInfo({AndroidDeviceInfo? androidDeviceInfo, IosDeviceInfo? iosDeviceInfo})
const

Properties

androidDeviceInfo → AndroidDeviceInfo?
final
data Map<String, dynamic>
no setter
hashCode int
The hash code for this object.
no setterinherited
iosDeviceInfo → IosDeviceInfo?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited