LinkUtil class abstract
Constructors
- LinkUtil()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
appLinkStream
→ Stream<
Uri> -
no setter
Static Methods
-
canOpenUri(
Uri uri) → Future< bool> - 检测链接是否可以打开
-
getInitialLink(
) → Future< Uri?> - 获取收到的链接
-
getLatestLink(
) → Future< Uri?> - 获取最新的链接
-
openAppSettings(
) → Future< void> - 打开系统设置
-
openUri(
Uri uri, {bool checkCanLaunch = false, LinkLaunchMode mode = LinkLaunchMode.platformDefault}) → Future< void> - 打开url链接