LogUtilLevel enum
日志等级
Values
- info → const LogUtilLevel
-
const LogUtilLevel(LogLevel.info, 'info') - warning → const LogUtilLevel
-
const LogUtilLevel(LogLevel.warning, 'warning') - error → const LogUtilLevel
-
const LogUtilLevel(LogLevel.error, 'error') - debug → const LogUtilLevel
-
const LogUtilLevel(LogLevel.debug, 'debug')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- level → LogLevel
-
final
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LogUtilLevel> - A constant List of the values in this enum, in order of their declaration.