VideoCompressionEstimate class

视频预估压缩结果

Constructors

VideoCompressionEstimate({required String estimatedSizeFormatted, required double compressionRatio, required double bitrateMbps, required int estimatedSizeBytes})
const
VideoCompressionEstimate.fromEstimate(VVideoCompressionEstimate estimate)
factory

Properties

bitrateMbps double
finalinherited
compressionRatio double
finalinherited
estimatedSizeBytes int
finalinherited
estimatedSizeFormatted String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited