VideoCompressionResult class

视频压缩结果

Constructors

VideoCompressionResult({required VVideoInfo originalVideo, required String compressedFilePath, required int originalSizeBytes, required int compressedSizeBytes, required double compressionRatio, required int timeTaken, required VVideoCompressQuality quality, required String originalResolution, required String compressedResolution, required int spaceSaved})

Properties

compressedFilePath String
finalinherited
compressedResolution String
finalinherited
compressedSizeBytes int
finalinherited
compressedSizeFormatted String
no setterinherited
compressionPercentage int
no setterinherited
compressionRatio double
finalinherited
galleryUri String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
originalResolution String
finalinherited
originalSizeBytes int
finalinherited
originalSizeFormatted String
no setterinherited
originalVideo → VVideoInfo
finalinherited
quality → VVideoCompressQuality
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaceSaved int
finalinherited
spaceSavedFormatted String
no setterinherited
timeTaken int
finalinherited
timeTakenFormatted String
no setterinherited
usedOriginalFile bool
Whether the original input file was returned instead of the encoded file.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited