CryptUtil class abstract
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
aesDecode(
{required String content, required String key}) → String - aes解密
-
aesEncode(
{required String content, required String key}) → String - aes加密
-
rsaDecrypt(
String encryptedStr, String privateKeyStr) → String -
RSA加密算法解密,秘钥格式为
pkcs8encryptedStr密文,base64编码privateKeyStr私钥 -
rsaEncrypt(
String content, String publicKeyStr) → String -
RSA加密算法加密,秘钥格式为
pkcs8content明文publicKeyStr公钥