AppLifecycle enum
Values
- inactive → const AppLifecycle
-
incative
const AppLifecycle('AppLifecycleState.inactive', 'inactive', '非活跃') - paused → const AppLifecycle
-
paused
const AppLifecycle('AppLifecycleState.paused', 'paused', '暂停') - resumed → const AppLifecycle
-
resumed
const AppLifecycle('AppLifecycleState.resumed', 'resumed', '恢复') - detached → const AppLifecycle
-
detached
const AppLifecycle('AppLifecycleState.detached', 'detached', '断开')
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String value) → AppLifecycle
Constants
-
values
→ const List<
AppLifecycle> - A constant List of the values in this enum, in order of their declaration.