Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
configLoading({Duration displayDuration = const Duration(milliseconds: 2000), EasyLoadingIndicatorType indicatorType = EasyLoadingIndicatorType.fadingCircle, EasyLoadingStyle loadingStyle = EasyLoadingStyle.dark, double indicatorSize = 45.0, double radius = 10.0, Color progressColor = Colors.yellow, Color backgroundColor = Colors.green, Color indicatorColor = Colors.yellow, Color textColor = Colors.yellow, Color maskColor = Colors.black54, bool userInteractions = true, bool dismissOnTap = false, EasyLoadingMaskType maskType = EasyLoadingMaskType.clear, EasyLoadingAnimation? customAnimation})
→ void
-
-
dismiss()
→ Future<void>
-
-
init({TransitionBuilder? builder})
→ TransitionBuilder
-
-
show()
→ Future<void>
-
-
showError(String message)
→ Future<void>
-
-
showInfo(String message)
→ Future<void>
-
-
showProgress(double progress)
→ Future<void>
-
-
showSuccess(String message)
→ Future<void>
-