LogUtil class abstract
日志工具类
Constructors
- LogUtil()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
no setter
- talker → Talker
-
no setter
- talkerDioLogger → TalkerDioLogger
-
no setter
- talkerPage → Widget
-
no setter
Static Methods
-
debug(
dynamic message, {Object? exception, StackTrace? stackTrace}) → void -
error(
dynamic message, {Object? exception, StackTrace? stackTrace}) → void -
info(
dynamic message, {Object? exception, StackTrace? stackTrace}) → void -
log(
dynamic message, {LogUtilLevel logLevel = LogUtilLevel.debug, Object? exception, StackTrace? stackTrace, AnsiPen? pen}) → void -
warning(
dynamic message, {Object? exception, StackTrace? stackTrace}) → void