PermissionUtil class abstract
权限工具类
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkPermission(
PermissionType permissonType) → Future< PermissionStatusType> - 检查权限状态
-
checkServiceStatus(
PermissionType permissonType) → Future< ServiceStatusType> - 检查系统服务状态
-
requestPermission(
PermissionType permissonType) → Future< PermissionStatusType> - 请求权限
-
requestPermissionList(
List< PermissionType> permissonTypeList) → Future<Map< PermissionType, PermissionStatusType> > - 批量请求权限