ThrottleUtil class
节流/防抖管理器
Constructors
- ThrottleUtil()
-
factory
Properties
-
debounceCache
→ Map<
String, _DebounceData> -
no setter
- debounceCacheSize → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
throttleCache
→ Map<
String, _ThrottleData> -
no setter
- throttleCacheSize → int
-
获取缓存大小
no setter
Methods
-
clearAll(
) → void - 清理所有缓存
-
clearDebounce(
String key) → void - 清理指定 key 的防抖缓存
-
clearThrottle(
String key) → void - 清理指定 key 的节流缓存
-
dispose(
) → void - 停止自动清理
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → ThrottleUtil
-
no setter