VideoCompressConfig class
视频压缩配置
Constructors
- VideoCompressConfig({required VVideoCompressQuality quality, VVideoAdvancedConfig? advanced, String? outputPath, bool deleteOriginal = false, bool saveToGallery = false, bool includeAudio = true, bool includeMetadata = true, bool optimizeForStreaming = true, bool useHardwareAcceleration = true, bool useFastStart = true, bool useTwoPassEncoding = false, bool useVariableBitrate = true, bool copyMetadata = true})
- VideoCompressConfig.high()
-
const
- VideoCompressConfig.low()
-
const
- VideoCompressConfig.medium()
-
const
- VideoCompressConfig.ultraLow()
-
const
- VideoCompressConfig.veryLow()
-
const
Properties
- advanced → VVideoAdvancedConfig?
-
Advanced compression settings (optional)
finalinherited
- copyMetadata → bool
-
Whether to copy metadata from original video
finalinherited
- deleteOriginal → bool
-
Whether to delete the original video file after compression
finalinherited
- fallbackToOriginalIfNotSmaller → bool
-
Whether to return the original file when compression saves less than 5%.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeAudio → bool
-
Whether to include audio in the compressed video
finalinherited
- includeMetadata → bool
-
Whether to include metadata in the compressed video
finalinherited
- optimizeForStreaming → bool
-
Whether to optimize for streaming
finalinherited
- outputPath → String?
-
Custom output path for the compressed video (optional)
finalinherited
- quality → VVideoCompressQuality
-
Quality level for the compressed video
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saveToGallery → bool
-
Whether to save the compressed video to gallery
finalinherited
- useFastStart → bool
-
Whether to use fast start
finalinherited
- useHardwareAcceleration → bool
-
Whether to use hardware acceleration
finalinherited
- useTwoPassEncoding → bool
-
Whether to use two pass encoding
finalinherited
- useVariableBitrate → bool
-
Whether to use variable bitrate
finalinherited
Methods
-
copyWith(
{VVideoCompressQuality? quality, VideoCompressAdvancedConfig? advanced, String? outputPath, bool? deleteOriginal, bool? saveToGallery}) → VideoCompressConfig -
isValid(
) → bool -
Validates the configuration
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited